Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ask ¶
type Ask struct {
Keyboard *keyboard.Watcher
Mouse *mouse.Watcher
// contains filtered or unexported fields
}
Ask provides methods for asking questions and getting user input with keyboard and mouse support
func (*Ask) ForBool ¶
ForBool prompts the user with a question and returns their boolean response It accepts "true", "false", "t", "f", "yes", "no", "y", "n", "1", "0" as valid inputs
func (*Ask) ForChoice ¶
ForChoice prompts the user with a question and a list of choices, and returns their selection
Click to show internal directories.
Click to hide internal directories.